#
# K2HASH
#
# Copyright 2013 Yahoo Japan Corporation.
#
# K2HASH is key-valuew store base libraries.
# K2HASH is made for the purpose of the construction of
# original KVS system and the offer of the library.
# The characteristic is this KVS library which Key can
# layer. And can support multi-processing and multi-thread,
# and is provided safely as available KVS.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Fri 17 Jul 2016
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.88

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: NoSQL Key Value Store(KVS) library
Name: k2hash
Version: 1.0.88
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Databases
URL: https://github.com/yahoojapan/k2hash
Source0: https://github.com/yahoojapan/k2hash/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: libfullock%{?_isa} >= 1.0.35
BuildRequires: git-core gcc-c++ make libtool libfullock-devel >= 1.0.35 nss-devel

%description
K2HASH is NoSQL(key value store) library and tools for this library by
Yahoo! JAPAN. K2HASH is following specifications.
- Supports multi-threading and multi-processing program.
- Expands data area.
- Switches accessing only memory and data file directly.
- Puts transaction.
- Archiving.
- Replaces hash function like plugin.
- Replaces transaction.

K2HASH tools can create/store(write)/read a file or memory which is
made(allocated) by K2HASH library for testing.

K2HASH library has following three way for KVS storage.
- Use storage on memory only, this type of storage can be used by
only multi-thread process. And on this type, the data on storage is
not permanent.
- Use fully mapping file, this type can be used by multi-thread and
multi-process. All of data in the file is mmapping fully, then the
limit of the file and data size depends on the memory.
- Use a part of mapping file and directly accessing a file, this type
can be used by multi-thread and multi-process.

K2HASH maps only hash table and etc from the file, and reads/writes the
file for datas directly. This way is expanding upper limit, but less
performance because directly accessing.

In cases of using mapping file, you can use the data(file) as perma-
nently or temporary.

K2HASH uses FNV-1a hashing function in it. If you replace this hash
function, you can do by two way.
- One way is that your process defines same prototype of hash func-
tion.
- The other is that you can load your original DSO library which in-
cludes same prototype of hash function.

You can know how to implement replacing hash function, please see
k2hashfunc.h file.

K2HASH can put transaction and archive all of data in file. If you need
to make your original formatted transaction outputs, you can do by two
way like replacing hash function.
- One way is that your process defines same prototype of hash func-
tion.
- The other is that you can load your original DSO library which in-
cludes same prototype of hash function.

You can know how to implement replacing transaction function, please
see k2htransfunc.h file.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static --with-nss
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
mkdir -p %{buildroot}/var/lib/antpickax

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%if 0%{?rhel} == 6
%clean
rm -rf %{buildroot}
%endif

%files
%if 0%{?rhel} == 6
%doc COPYING
%defattr(-,root,root)
%else
%license COPYING
%endif
%doc README AUTHORS ChangeLog
%{_libdir}/*.so.1*
%{_mandir}/man1/*
%{_bindir}/*
%dir %attr(0777,root,root) /var/lib/antpickax

#
# devel package
#
%package devel
Summary: NoSQL Key Value Store(KVS) library (development)
Requires: %{name}%{?_isa} = %{version}-%{release}, libfullock-devel%{?_isa} >= 1.0.35, nss-devel

%description devel
Development package for building with k2hash shared library.
This package has header files and symbols for it.

%files devel
%if 0%{?rhel} == 6
%defattr(-,root,root)
%endif
%doc README AUTHORS ChangeLog
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Jun 21 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.88-1
- Fixed .gitignore to exclude APKBUILD.templ - #89

* Tue Feb 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.87
- Updated build helper scripts on CI process - #87

* Tue Feb 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.86
- Updated building/packaging logic for ALPINE - #85

* Wed Feb 08 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.85
- Fixed package dependency and docker image for ALPINE - #83

* Fri Feb 03 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.84
- Changed CI process flow/OSs and added Alpine OS - #81
- Updated header and footer in comment lines - #79
- Updated issue/pullrequest templates and README - #78
- Updated Makefile.am about cppcheck - #77
- Added ShellCheck processing and reviewed cppcheck - #76
- Eliminated unnecessary copies in build_helper.sh - #75
- Updated docker/login-action from v1 to v2 - #74
- Shared Docker image build logic with other products - #73
- Removed K2HATTR_ENC_TYPE environment for building - #72
- Updated github actions process and support os, and fixed bugs - #71
- Updated debian_build.sh for changing grep parameter - #70
- Updated common build scripts - #69
- Updated Antpickax common scripts and tools under the buildutils directory - #68
- Fixed errors reported by cppcheck 2.9 - #67
- Updated .gitignore configure.ac - #66
- Enabled external customization of configure.ac and fixed for building - #65

* Fri Aug 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.83
- Fixed Dockerfile template for calling ldconfig - #63

* Tue Aug 17 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.82
- Fixed a bug in Docker image build - #61

* Mon Aug 16 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.81
- Fixed to create /var/lib/antpickax at installation - #59

* Tue Aug 10 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.80
- Added docker build and push in Github Actions - #57
- Functional improvements and bug fixes - #56

* Wed Jan 27 2021 Hirotaka Wakabayashi <hiwakaba@yahoo-corp.jp> 1.0.79
- Fixes the cppcheck error - #54
- Updates editor setting variables - #54
- Fixes a queue remove command bug in k2hlinetool - #54

* Wed Dec 16 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.78
- Fixed centos8 build and removed centos6 build - #47

* Tue Nov 24 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.77
- Fixed a error by cppcheck 2.2 - #45

* Mon Nov 16 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.76
- Updated README.md for Github Actions status - #43

* Mon Nov 16 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.75
- Switched Travis CI to Github actions and extended supported OS - #41
- Fixed bugs detected by cppcheck - #40

* Fri Apr 03 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.74
- Allow 0 sec for expire when setting directly as placeholder - #38

* Tue Feb 25 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.73
- Stopped deleting monitor files of the last process - #36

* Tue Feb 18 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.72
- Enhanced lock of monitor file parts - #34

* Fri May 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.71
- Fixed a bug that leaked file descriptor - #31

* Tue Mar 12 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.70
- Fixed codes for cppcheck 1.87 - #28

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.69
- Fixed incorporation of multibyte characters - #25
- Added check using cppcheck - #24
- Reflected the spelling check result for all sources - #23
- Remove dead code - #21

* Tue Dec 11 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.68
- Updated common build tool files

* Wed Dec 05 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.67
- Updated configure.ac and packaging scripts/files

* Fri Nov 30 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.66
- Fixed bug in debian package creation

* Thu Nov 29 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.65
- Changed to strict packaging and changed documents

* Wed Nov 07 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.64
- Fixed a bug segmentation fault exiting tr thread

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.63
- Fixed requires in specfile
- Fixed fatal error in destructor code corresponding to SIOF etc

* Thu Oct 04 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.62
- Fixed fatal error in destructing mmap info and etc

* Fri Jun 29 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.61
- avoid static object initialization order problem(SIOF)

* Tue Jun 26 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.60
- Fixed build options for pthread

* Thu Jun 21 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.59
- Fixed a bug about lead loop

* Wed May 16 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.58
- Cleanup credit comments in sources
- Supported multi crypt libraries(NSS/gcrypt/nettle)
- Changed build logic to new for rpm/debian packaging
- Fixed build error with openssl 1.1.0

* Wed May 17 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.57
- Fixed type qualifiers ignored on function return type

* Tue Mar 28 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.56
- Strict/Robust queue processing for conflicting
- Fixed deadlock at updating key with subkeys

* Tue Mar 21 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.55
- Updated fullock submodule v1.0.24
- Added lib_version_for_link option to make_valiables.sh
- Fixed failed adding subkeys to encrypted key with no value

* Tue Feb 14 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.54
- Updated dependency for fixing bugs in libfullock

* Mon Feb 06 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.53
- Fixed mistaking codes - #3
- Fixed error/warning for compiling and changed travis.yaml - #2

* Wed Dec 07 2016 Takeshi Nakatani <ggtakec@gmail.com> 1.0.52
- First version of open sorce on Github
